@@ -3,11 +3,12 @@
 from __future__ import absolute_import
 import sys
 import re
+import copy
 import xml.etree.ElementTree as ET
 
 from svtplay_dl.service import Service
-from svtplay_dl.utils import get_http_data, select_quality, is_py2_old
-from svtplay_dl.fetcher.http import download_http
+from svtplay_dl.utils import get_http_data, is_py2_old
+from svtplay_dl.fetcher.http import HTTP
 
 from svtplay_dl.log import log
 
@@ -29,13 +30,8 @@ class Mtvservices(Service):
             sa = list(ss.getiterator("rendition"))
         else:
             sa = list(ss.iter("rendition"))
-        streams = {}
+
         for i in sa:
-            streams[int(i.attrib["height"])] = i.find("src").text
-        if len(streams) == 0:
-            log.error("Can't find video file: %s", ss.text)
-            sys.exit(2)
-        stream = select_quality(options, streams)
-        temp = stream.index("gsp.comedystor")
-        url = "http://mtvnmobile.vo.llnwd.net/kip0/_pxn=0+_pxK=18639+_pxE=mp4/44620/mtvnorigin/%s" % stream[temp:]
-        download_http(options, url)
+            temp = i.find("src").text.index("gsp.comedystor")
+            url = "http://mtvnmobile.vo.llnwd.net/kip0/_pxn=0+_pxK=18639+_pxE=mp4/44620/mtvnorigin/%s" % i.find("src").text[temp:]
+            yield HTTP(copy.copy(options), url, i.attrib["height"])
