@@ -4,12 +4,14 @@ from __future__ import absolute_import
 import re
 import sys
 import json
+import copy
 
 from svtplay_dl.service import Service, OpenGraphThumbMixin
-from svtplay_dl.utils import get_http_data, subtitle_tt
+from svtplay_dl.utils import get_http_data
 from svtplay_dl.utils.urllib import urlparse
-from svtplay_dl.fetcher.hds import download_hds
-from svtplay_dl.fetcher.hls import download_hls
+from svtplay_dl.fetcher.hds import hdsparse
+from svtplay_dl.fetcher.hls import HLS, hlsparse
+from svtplay_dl.subtitle import subtitle_tt
 from svtplay_dl.log import log
 
 class Nrk(Service, OpenGraphThumbMixin):
@@ -17,6 +19,15 @@ class Nrk(Service, OpenGraphThumbMixin):
 
     def get(self, options):
         data = self.get_urldata()
+        match = re.search("data-subtitlesurl = \"(/.*)\"", data)
+        if match:
+            parse = urlparse(self.url)
+            subtitle = "%s://%s%s" % (parse.scheme, parse.netloc, match.group(1))
+            yield subtitle_tt(subtitle)
+
+        if options.force_subtitle:
+            return
+
         match = re.search(r'data-media="(.*manifest.f4m)"', data)
         if match:
             manifest_url = match.group(1)
@@ -34,19 +45,14 @@ class Nrk(Service, OpenGraphThumbMixin):
             data = json.loads(get_http_data(dataurl))
             manifest_url = data["mediaUrl"]
             options.live = data["isLive"]
-        if options.hls:
-            manifest_url = manifest_url.replace("/z/", "/i/").replace("manifest.f4m", "master.m3u8")
-            download_hls(options, manifest_url)
-        else:
-            manifest_url = "%s?hdcore=2.8.0&g=hejsan" % manifest_url
-            download_hds(options, manifest_url)
 
+        hlsurl = manifest_url.replace("/z/", "/i/").replace("manifest.f4m", "master.m3u8")
+        streams = hlsparse(hlsurl)
+        for n in list(streams.keys()):
+            yield HLS(copy.copy(options), streams[n], n)
 
-    def get_subtitle(self, options):
-        match = re.search("data-subtitlesurl = \"(/.*)\"", self.get_urldata())
-        if match:
-            parse = urlparse(self.url)
-            subtitle = "%s://%s%s" % (parse.scheme, parse.netloc, match.group(1))
-            data = get_http_data(subtitle)
-            subtitle_tt(options, data)
-
+        manifest_url = "%s?hdcore=2.8.0&g=hejsan" % manifest_url
+        streams = hdsparse(copy.copy(options), manifest_url)
+        if streams:
+            for n in list(streams.keys()):
+                yield streams[n]
