@@ -8,12 +8,13 @@ from __future__ import absolute_import
 import sys
 import json
 import re
+import copy
 
 from svtplay_dl.utils.urllib import quote_plus
 from svtplay_dl.service import Service, OpenGraphThumbMixin
-from svtplay_dl.utils import get_http_data, select_quality
+from svtplay_dl.utils import get_http_data
 from svtplay_dl.log import log
-from svtplay_dl.fetcher.http import download_http
+from svtplay_dl.fetcher.http import HTTP
 
 class Sr(Service, OpenGraphThumbMixin):
     supported_domains = ['sverigesradio.se']
@@ -27,13 +28,10 @@ class Sr(Service, OpenGraphThumbMixin):
         dataurl = "http://sverigesradio.se/sida/ajax/getplayerinfo?url=%s&isios=false&playertype=html5" % path
         data = get_http_data(dataurl)
         playerinfo = json.loads(data)["playerInfo"]
-        streams = {}
         for i in playerinfo["AudioSources"]:
             url = i["Url"]
             if not url.startswith('http'):
-                i = 'http:%s' % url
-            streams[int(i["Quality"])] = url
+                url = 'http:%s' % url
+            yield HTTP(copy.copy(options), url, i["Quality"])
 
-        test = select_quality(options, streams)
-        download_http(options, test)
 
